pub enum Link {
Ref {
operation_ref: String,
parameters: Option<BTreeMap<String, String>>,
description: Option<String>,
server: Option<Server>,
extensions: Extensions,
},
Id {
operation_id: String,
parameters: Option<BTreeMap<String, String>>,
description: Option<String>,
server: Option<Server>,
extensions: Extensions,
},
}Expand description
The Link object represents a possible design-time link for a response.
The presence of a link does not guarantee the caller’s ability to successfully invoke it, rather it provides a known relationship and traversal mechanism between responses and other operations.
Unlike dynamic links (i.e. links provided in the response payload), the OAS linking mechanism does not require link information in the runtime response.
For computing links, and providing instructions to execute them, a runtime expression is used for accessing values in an operation and using them as parameters while invoking the linked operation.
Variants
Ref
A relative or absolute reference to an OAS operation. This field is mutually exclusive
of the operationId field, and MUST point to an
Operation Object.
Relative operationRef values MAY be used to locate an existing
Operation Object
in the OpenAPI definition.
Fields
description: Option<String>A description of the link. CommonMark syntax MAY be used for rich text representation.
extensions: ExtensionsId
The name of an existing, resolvable OAS operation, as defined with a unique
operationId. This field is mutually exclusive of the operationRef field.